@@ -20,7 +20,7 @@ warnings.filterwarnings(
     message='^pandas.util.testing is deprecated'
 )
 
-__version__ = '1.14.0'
+__version__ = '1.16.0'
 __product__ = "ihsm-datalake"
 
 
@@ -41,13 +41,12 @@ except ImportError:
 
 
 def connect(
-    api_key=None,
     root_url="https://catalogue.datalake.ihsmarkit.com/__api",
-    host=None,
     debug=None,
     strict=True,
     use_keyring=True,
     log_level=None,
+    show_login_url=False,
 ):
     """
     Entry point for the Data Lake SDK, returns a client instance that
@@ -61,16 +60,8 @@ def connect(
         import dli
         client = client.connect()
 
-    :param str api_key: Your API key, can be retrieved from your dashboard in
-                        the Catalogue UI.
     :param str root_url: Optional. The environment you want to point to. By default it
                         points to Production.
-    :param str host: Optional. Advanced usage, meant to force a hostname when DNS resolution
-                     is not reacheable from the user's network.
-                     This is meant to be used in conjunction with an
-                     IP address as the root url.
-                     Example: catalogue.datalake.ihsmarkit.com
-
     :param bool debug: Optional. Log SDK operations to a file in the current working
                        directory with the format "sdk-{end of api key}-{timestamp}.log"
 
@@ -84,20 +75,15 @@ def connect(
     :returns: Data Lake interface client
     :rtype: dli.client.dli_client.DliClient
 
-    .. deprecated:: 1.8.3
-
-        `api_key`: please use the basic flow or client credentials.
-
     """
     from dli.client.session import _start_session
 
     return _start_session(
-        api_key,
         root_url=root_url,
-        host=host,
         debug=debug,
         strict=strict,
         use_keyring=use_keyring,
         log_level=log_level,
+        show_login_url=show_login_url,
     )
 
