@@ -1,9 +1,69 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
+import threading
+import queue
+
 from urllib.parse import urljoin
 
 import dli
 from dli.client.components.urls import consumption_urls
 
 
+class AnalyticsSender(threading.Thread):
+
+    BUFFER_THREASHOLD = 10
+
+    def __init__(self, client):
+        super().__init__()
+        self.daemon = True
+        self._client = client
+        self.queue = queue.Queue()
+        self._buffer = []
+
+    def run(self):
+        while True:
+            # Send buffer every 5 seconds
+            try:
+                event = self.queue.get(block=True, timeout=5)
+                if event is None:
+                    # end thread
+                    break
+
+                self._buffer.append(event)
+
+                if len(self._buffer) > self.BUFFER_THREASHOLD:
+                    self._send_buffer()
+            except queue.Empty:
+                # Means we've timed out.
+                # send what's in the buffer
+                self._send_buffer()
+                continue
+
+    def _send_buffer(self):
+        try:
+            if len(self._buffer):
+                url = urljoin(
+                    self._client._environment.consumption,
+                    consumption_urls.consumption_analytics
+                )
+                session = self._client.session
+                session.post(url, json={
+                    'data': self._buffer
+                })
+
+                self._buffer = []
+
+        except Exception as e:
+            # Data scientists do not want to see stack dumps by default,
+            # especially when we have a root cause that triggers secondary
+            # exceptions.
+            if self._client.strict:
+                self._client.logger.exception(
+                    'Error while sending analytics: ', e
+                )
+
 class AnalyticsHandler:
     __acceptable_properties = [
         'package_id', 'dataset_id', 'name', 'dataset_name', 'datafile_id',
@@ -14,27 +74,18 @@ class AnalyticsHandler:
         self._app_name = 'SDK'
         self._app_version = dli.__version__
         self._client = dli_client
-        self._logger = dli_client.logger
+        self._analytics_sender = AnalyticsSender(dli_client)
+        self._analytics_sender.start()
 
     def create_event(
         self, user_id, organisation_id,
         entity=None, action=None, properties=None, result_status_code=None
     ):
-        self._log_call_handling_exceptions(
+        body = self._prepare_body_to_send(
             user_id, organisation_id, entity, action, properties,
-            result_status_code
+            result_status_code,
         )
-
-    def _log_call_handling_exceptions(
-        self, user_id, organisation_id, entity, action, properties, result
-    ):
-        try:
-            body = self._prepare_body_to_send(
-                user_id, organisation_id, entity, action, properties, result,
-            )
-            self._send_event_to_analytics(body)
-        except Exception as e:
-            self._logger.exception('Error while sending analytics: ', e)
+        self._send_event_to_analytics(body)
 
     def _prepare_body_to_send(
         self, user_id, organisation_id, entity, action, properties, result
@@ -42,8 +93,7 @@ class AnalyticsHandler:
         properties_to_send = self._filter_out_properties(properties)
         properties_to_send = self._override_properties_for_dataset_functions(
             action, entity, properties, properties_to_send)
-        if 'api_key' in properties:
-            properties['api_key'] = properties['api_key'][:6]
+
         event = {
             'application_name': self._app_name,
             'application_version': self._app_version,
@@ -54,8 +104,7 @@ class AnalyticsHandler:
             'result': result,
             'properties': properties_to_send
         }
-        body = {'data': [{'attributes': event}]}
-        return body
+        return {'attributes': event}
 
     def _filter_out_properties(self, properties):
         return {
@@ -77,10 +126,9 @@ class AnalyticsHandler:
                 props['dataset_id'] = properties['id']
         return props
 
+    def __del__(self):
+        # tell the queue it's over
+        self._analytics_sender.queue.put(None)
+
     def _send_event_to_analytics(self, body):
-        url = urljoin(
-            self._client._environment.consumption,
-            consumption_urls.consumption_analytics
-        )
-        session = self._client.session
-        session.post(url, json=body)
+        self._analytics_sender.queue.put(body)
