@@ -10,6 +10,7 @@ from requests_toolbelt.multipart.encoder import MultipartEncoder
 
 TEN_MEGABYTES = 10485760
 
+
 class DatasetBuilder:
     """
     Dataset is grouping of related datafiles. It provides user with metadata required to consume and use the data.
@@ -22,7 +23,7 @@ class DatasetBuilder:
                     belongs to.
     :param str description: A short description of the dataset.
     :param str content_type: A way for the data steward to classify the type of data in the dataset
-                        (e.g. pricing).
+                        (e.g. Structured or Unstructured).
     :param str data_format: The format of the data: `CSV`, `IMAGE`, `JSON`, `PARQUET`, `TXT`, `TSV`,`XML`, `Other`.
     :param str publishing_frequency: The internal on which data is published. Possible values are: `Hourly`,
                                         `Daily`, `Weekday`, `Weekly`, `Monthly`, `Quarterly`, `Yearly`, `Not Specified`.
@@ -39,6 +40,7 @@ class DatasetBuilder:
     :param str load_type: Optional. Whether each datafile in this dataset should be considered as a full version of a
                         dataset or a delta or increment. Accepted types are `Full Load`, `Incremental Load`
     :param str has_datafile_monitoring: Optional. Notify when latest instance is missing
+    :param bool details_visible_to_lite_users: Optional. Default value "False".
 
     # XXX
     :param str data_preview_type: Optional enum of NONE STATIC LIVE. 'NONE' means there is no datapreview. STATIC means to use the file provided. LIVE means to use the latest datafile.
@@ -46,7 +48,7 @@ class DatasetBuilder:
     """
 
     @staticmethod
-    def _create_dliv1_paylod(
+    def _create_dliv1_payload(
         package_id=None,
         name=None,
         description=None,
@@ -58,6 +60,8 @@ class DatasetBuilder:
         naming_convention=None,
         documentation=None,
         load_type=None,
+        has_datafile_monitoring=None,
+        details_visible_to_lite_users=None,
         **kwargs
     ):
         return {
@@ -72,7 +76,9 @@ class DatasetBuilder:
             "namingConvention": naming_convention,
             "documentation": documentation,
             "taxonomy": taxonomy,
-            "loadType": load_type
+            "loadType": load_type,
+            "has_datafile_monitoring": has_datafile_monitoring,
+            "details_visible_to_lite_users": details_visible_to_lite_users,
         }
 
     def __init__(self, location_builder=None, **kwargs):
@@ -88,7 +94,7 @@ class DatasetBuilder:
             )
 
         # this is just for DLI v1 TODO add deprecated to it.
-        self.payload = self._create_dliv1_paylod(**self._data)
+        self.payload = self._create_dliv1_payload(**self._data)
         self._location_builder = location_builder
 
     def to_json_api(self):
@@ -166,7 +172,7 @@ class DatasetBuilder:
                                 package_id="package-id",
                                 name="my test dataset",
                                 description="My dataset description",
-                                content_type="Pricing",
+                                content_type="Structured",
                                 data_format="CSV",
                                 publishing_frequency="Weekly",
                                 taxonomy=["Credit", "CDS"]
@@ -210,7 +216,7 @@ class DatasetBuilder:
                                 package_id="package-id",
                                 name="my test dataset",
                                 description="My dataset description",
-                                content_type="Pricing",
+                                content_type="Structured",
                                 data_format="CSV",
                                 publishing_frequency="Weekly",
                                 taxonomy=["Credit", "CDS"]
@@ -324,8 +330,8 @@ class DatasetLocationBuilder:
         have to handle both cases.
         """
         data = {}
-
-        if self.payload['location']['type'] == 'S3':
+        location = None if 'location' not in self.payload else self.payload['location']
+        if location and location['type'] == 'S3':
             data['location'] = {
                 's3': copy.copy(self.payload['location'])
             }
