@@ -1,17 +1,24 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
 import datetime
 import logging
 import posixpath
+import warnings
 
+from dli.client.components import BaseComponent
 from dli.client.components.urls import datafile_urls
-from dli.client.components import SirenComponent
-from dli.client.exceptions import DownloadFailed
+from dli.client.exceptions import DownloadFailed, DatalakeException
 from dli.client.s3 import Client, S3DatafileWrapper
-from dli.siren import siren_to_dict, siren_to_entity
+from dli.client.utils import to_snake_case_keys, _AttributeAdapter, object_to_namedtuple
+from dli.models.dataset_model import DatasetModel
+from typing import Dict
 
 logger = logging.getLogger(__name__)
 
 
-class Datafile(SirenComponent):
+class Datafile(BaseComponent):
 
     def register_datafile_metadata(
         self,
@@ -53,10 +60,19 @@ class Datafile(SirenComponent):
                     data_as_of="2018-05-28"
                 )
         """
-        dataset = self.get_dataset(id=dataset_id)
+        ds: Dict[str, DatasetModel] = self.datasets(search_term=[f"id={dataset_id}"])
+        num_matches = len(ds)
+        if num_matches == 0:
+            raise DatalakeException(f"No such dataset ID `{dataset_id}`")
+        elif num_matches > 1:
+            # This should not be possible, but let's cover this scenario incase Caatlogue returns
+            # bad data.
+            raise DatalakeException(f"More than one dataset with ID `{dataset_id}`")
+        else:
+            dataset: DatasetModel = list(ds.values())[0]
 
         if not files:
-            raise Exception("No files to register have been provided.")
+            raise DatalakeException("No files to register have been provided.")
 
         fields = {
             'datasetId': dataset.dataset_id,
@@ -68,11 +84,11 @@ class Datafile(SirenComponent):
 
         payload = {k: v for k, v in fields.items() if v is not None}
 
-        return siren_to_entity(
-            self.session.post(
-                datafile_urls.datafiles_index, json=payload
-            ).to_siren()
-        )
+        response_dict = self.session.post(
+                    datafile_urls.datafiles_index, json=payload
+                ).json()
+        obj = type(response_dict['class'][0], (_AttributeAdapter,), to_snake_case_keys(response_dict["properties"]))()
+        return obj
 
     def register_s3_datafile(
         self,
@@ -116,17 +132,31 @@ class Datafile(SirenComponent):
                     data_as_of="2018-05-28"
                 )
         """
-        dataset = self.get_dataset(id=dataset_id)
+        ds: Dict[str, DatasetModel] = self.datasets(search_term=[f"id={dataset_id}"])
+        num_matches = len(ds)
+        if num_matches == 0:
+            raise Exception(f"No such dataset ID `{dataset_id}`")
+        elif num_matches > 1:
+            # This should not be possible, but let's cover this scenario incase Caatlogue returns
+            # bad data.
+            raise Exception(f"More than one dataset with ID `{dataset_id}`")
+        else:
+            dataset: DatasetModel = list(ds.values())[0]
 
         if not files:
             raise Exception("No files to register have been provided.")
 
         # upload files
-        if dataset.location.type != 'S3':
+        location = None if hasattr(dataset, 'location') is False else dataset.location
+        if not location:
+            raise Exception(
+                f"No access to specified dataset.")
+
+        if location.type != 'S3':
             raise Exception(
                 "Only datasets backed on S3 are supported. use register_datafile_metadata instead.")
 
-        bucket = dataset.location.bucket
+        bucket = location.bucket
         if not bucket:
             raise Exception(
                 "Dataset location is S3, however, "
@@ -136,7 +166,8 @@ class Datafile(SirenComponent):
 
         s3_location = "{}/{}".format(bucket, s3_prefix)
         uploaded = self._process_s3_upload(files, s3_location, dataset_id)
-        # register metadata
+
+
         return self.register_datafile_metadata(
             dataset_id,
             name=name,
@@ -190,7 +221,8 @@ class Datafile(SirenComponent):
         }
 
         # clean up any unknown fields, and update the entity
-        datafile_as_dict = siren_to_dict(datafile)
+        datafile_as_dict = datafile.as_dict()
+
         for key in list(datafile_as_dict.keys()):
             if key not in fields:
                 del datafile_as_dict[key]
@@ -199,12 +231,13 @@ class Datafile(SirenComponent):
         datafile_as_dict.update(payload)
 
         # perform the update and return the resulting entity
-        response = self.session.put(
+        response_dict = self.session.put(
             datafile_urls.datafiles_instance.format(id=datafile_id),
             json=datafile_as_dict
-        )
-
-        return siren_to_entity(response.to_siren())
+        ).json()
+        obj = type(response_dict['class'][0], (_AttributeAdapter,), to_snake_case_keys(response_dict["properties"]))()
+        named_tuple_obj = object_to_namedtuple(obj)
+        return named_tuple_obj
 
     def delete_datafile(self, datafile_id):
         """
@@ -226,6 +259,8 @@ class Datafile(SirenComponent):
 
     def get_s3_datafile(self, datafile_id):
         """
+        .. deprecated:: 1.8.0
+
         Fetches an S3 datafile providing easy access to directly
         stream/load files without the need of downloading them.
 
@@ -250,6 +285,12 @@ class Datafile(SirenComponent):
                 datafile.files  # displays a list of files in this datafile
 
         """
+        warnings.warn(
+            '.get_s3_datafile is deprecated. '
+            'Please use dataset.download() instead.',
+            DeprecationWarning
+        )
+
         datafile = self.get_datafile(datafile_id)
         s3_access = Client.from_dataset(self, datafile.dataset_id)
         return S3DatafileWrapper(datafile._asdict(), s3_access)
@@ -266,9 +307,25 @@ class Datafile(SirenComponent):
           - s3
 
         :param str datafile_id: The id of the datafile we want to download files from.
-        :param str destination: Target location where to store the files (expected to be a directory).
-        :param bool flatten: The s3 file structure is used by default (=False) when
-            downloading the files.
+
+        :param str destination: required. The path on the system, where the
+            files should be saved. must be a directory, if doesn't exist, will
+            be created.
+
+        :param bool flatten: The default behaviour (=False) is to use the s3
+            file structure when writing the downloaded files to disk. Example:
+            [
+              'storm/climate/storm_data/storm_fatalities/as_of_date=2019-09-10/type=full/StormEvents_details-ftp_v1.0_d1950_c20170120.csv.gz',
+              'storm/climate/storm_data/storm_fatalities/as_of_date=2019-09-10/type=full/StormEvents_details-ftp_v1.0_d1951_c20160223.csv.gz'
+            ]
+
+            When flatten = True, we remove the s3 structure. Example:
+
+            Example output for new behaviour:
+            [
+              './storm-flattened/StormEvents_details-ftp_v1.0_d1950_c20170120.csv.gz',
+              './storm-flattened/StormEvents_details-ftp_v1.0_d1951_c20160223.csv.gz'
+            ]
 
         :returns: a list of the paths where the files were downloaded
             to e.g. ['path/git /package/dataset/as_of_date=2019-10-16
@@ -333,16 +390,19 @@ class Datafile(SirenComponent):
 
                 datafile = client.get_datafile(datafile_id)
         """
-        datafile = self._get_datafile(datafile_id)
+        datafile = self._get_datafile(datafile_id, snake_case=True)
 
-        return siren_to_entity(datafile)
+        return object_to_namedtuple(datafile)
 
-    def _get_datafile(self, datafile_id):
-        response = self.session.get(
+    def _get_datafile(self, datafile_id, snake_case: bool = False):
+        response_dict = self.session.get(
             datafile_urls.datafiles_instance.format(id=datafile_id)
-        )
-
-        return response.to_siren()
+        ).json()
+        if snake_case:
+            obj = type(response_dict['class'][0], (_AttributeAdapter,), to_snake_case_keys(response_dict["properties"]))()
+        else:
+            obj = type(response_dict['class'][0], (_AttributeAdapter,), response_dict["properties"])()
+        return obj
 
     def add_files_to_datafile(self, datafile_id, s3_prefix, files):
         """
@@ -366,7 +426,22 @@ class Datafile(SirenComponent):
                                                         )
         """
         datafile = self.get_datafile(datafile_id)
-        dataset = self.get_dataset(id=datafile.dataset_id)
+        dataset_id = datafile.dataset_id
+
+        ds: Dict[str, DatasetModel] = self.datasets(search_term=[f"id={dataset_id}"])
+        num_matches = len(ds)
+        if num_matches == 0:
+            raise Exception(f"No such dataset ID `{dataset_id}`")
+        elif num_matches > 1:
+            # This should not be possible, but let's cover this scenario incase Caatlogue returns
+            # bad data.
+            raise Exception(f"More than one dataset with ID `{dataset_id}`")
+        else:
+            dataset: DatasetModel = list(ds.values())[0]
+
+        location = None if hasattr(dataset, 'location') is False else dataset.location
+        if not location:
+            raise Exception("No access to dataset.")
 
         if dataset.location.type != "S3":
             raise Exception("Can not upload files to non-S3 datasets.")
