@@ -5,9 +5,11 @@
 import base64
 import datetime
 import os
+import re
 import sys
 import time
 import webbrowser
+from abc import ABC
 from json import JSONDecodeError
 import warnings
 import uuid
@@ -40,7 +42,7 @@ from dli.client.exceptions import (
     InvalidPayloadException, UnAuthorisedAccessException,
     CatalogueEntityNotFoundException, AuthenticationFailure,
     DatalakeGatewayTimeout, DatalakeServiceUnavailable,
-    DatalakePayloadTooLargeException, TimeoutException
+    DatalakePayloadTooLargeException, ConnectionException
 )
 from dli.models.paginator import Paginator
 from dli.models.structured_dataset_model import StructuredDatasetModel
@@ -53,11 +55,11 @@ from dli.models.instance_model import InstanceModel, \
     InstancesCollection as InstancesCollection_
 from dli.models.package_model import PackageModel
 from dli.models.dataset_factory import DatasetFactory
-from dli.siren import PatchedSirenBuilder
 from dli.boto_authenticator import BotoAuthenticator
 
 trace_logger = logging.getLogger('trace_logger')
 
+
 class DliClient(AutoRegMetadata,
                 Datafile, Dataset, Dictionary,
                 Package):
@@ -82,16 +84,16 @@ class DliClient(AutoRegMetadata,
 
     _environment_class = _Environment
 
-    def __init__(self, api_root, host=None, debug=None, strict=True,
-                 access_id=None, secret_key=None, use_keyring=True):
+    def __init__(self, api_root, debug=None, strict=True,
+                 access_id=None, secret_key=None, use_keyring=True, show_login_url=False):
         self._environment = self._environment_class(api_root)
         self.access_id = access_id
         self.secret_key = secret_key
-        self.host = host
         self.debug = debug
         self.strict = strict
         self.use_keyring = use_keyring
         self.logger = logging.getLogger(__name__)
+        self.show_login_url = show_login_url
 
         self.logger.debug(
             'Starting SDK session',
@@ -109,25 +111,16 @@ class DliClient(AutoRegMetadata,
         self.packages = self._packages()
         self.datasets = self._datasets()
 
-        if access_id is None and secret_key is not None:
-            warnings.warn(
-                'The parameter `api_key` will be deprecated in the future. '
-                'We will be contacting users in the following months to '
-                'explain how to migrate to the new authentication flow.',
-                PendingDeprecationWarning
-            )
-
         self._boto_authenticator = None
 
-
     def _new_session(self):
         session = Session(
             self.access_id,
             self.secret_key,
             self._environment,
-            self.host,
             logger=self.logger,
-            use_keyring=self.use_keyring
+            use_keyring=self.use_keyring,
+            show_login_url=self.show_login_url,
         )
         return session
 
@@ -175,8 +168,8 @@ class Session(requests.Session):
     ]
 
     def __init__(
-        self, access_id, secret_key, environment, host, logger,
-        auth_key=None, auth_prompt=True, use_keyring=True
+        self, access_id, secret_key, environment, logger,
+        auth_key=None, auth_prompt=True, use_keyring=True, show_login_url=False
     ):
         super().__init__()
         self.auth_key = None
@@ -185,8 +178,8 @@ class Session(requests.Session):
         self.secret_key = secret_key
         self._environment = environment
         self.use_keyring = use_keyring
-        self.host = host
-        self.siren_builder = PatchedSirenBuilder()
+        self.show_login_url = show_login_url
+
         if auth_prompt:
             self._auth_init(auth_key)
         # mount points to add headers to specific routing requests
@@ -296,11 +289,8 @@ class Session(requests.Session):
             self.auth_key = self._get_web_auth_key()
 
     def _auth_init(self, auth_key=None):
-
         if auth_key:
             self.auth_key = auth_key
-        elif self.secret_key and not self.access_id:
-            self.auth_key = self._get_auth_key()
         elif self.access_id and self.secret_key:
             self.auth_key = self._get_SAM_auth_key()
         else:
@@ -314,18 +304,32 @@ class Session(requests.Session):
         return timeout
 
     def request(self, method, url, *args, **kwargs):
+        headers = kwargs.pop('headers', {})
+
         if not urlparse(url).netloc:
-            url = urljoin(self._environment.catalogue, url)
+
+            # HACK, todo 2020-07
+            # we have this because catalogue has ingress rules to map back to identity based on the /identity/ regex
+            # we could instead setup nginx ingress in docker, but its heavy-weight. So if DEV_MODE is set
+            # we just target identity directly, if the url matches the nginx rule (exported from nginx) below.
+            # we then need to patch the jwt back on to send directly to identity
+            if os.environ.get('DEV_MODE'):
+                identity = re.compile("/api/identity(/|${literal_dollar})(.*)")
+                if identity.match(url):
+                    url = urljoin(os.environ.get('DATA_LAKE_ACCOUNTS_URL'), url.replace("/api/identity", ""))
+                    headers["Authorization"] = f"Bearer {self.auth_key}"
+                else:
+                    url = urljoin(self._environment.catalogue, url)
+            else:
+                url = urljoin(self._environment.catalogue, url)
 
         kwargs.pop('hooks', None)
         hooks = {'response': self._response_hook}
         timeout = self._get_timeout()
 
-        headers = kwargs.pop('headers', {})
         # Adding this here in order to log the request ID
         request_id = str(uuid.uuid4())
         headers['X-Request-ID'] = request_id
-
         try:
             self.logger.debug(
                 f'{method} Request to {url} with request_id: {request_id}',
@@ -342,7 +346,7 @@ class Session(requests.Session):
                 method, url, hooks=hooks, timeout=timeout, headers=headers, *args, **kwargs
             )
         except requests.exceptions.ConnectionError as e:
-            raise TimeoutException(e)
+            raise ConnectionException(e)
         except socket.error as e:
             raise ValueError(
                 'Unable to process request due to a networking issue '
@@ -359,10 +363,6 @@ class Session(requests.Session):
                (self.token_expires_on - datetime.timedelta(minutes=1))
 
     def _response_hook(self, response, *args, **kwargs):
-        # Apologies for the ugly code. The startswith siren check
-        # is to make this only relevant to the old API.
-        response = Response(response, self.siren_builder)
-
 
         if self.logger:
             self.logger.debug(
@@ -395,7 +395,6 @@ class Session(requests.Session):
                  }
             )
 
-
             try:
                 message = response.json()
             except (JSONDecodeError, ValueError):
@@ -468,24 +467,6 @@ class Session(requests.Session):
             self.decoded_token['exp']
         ) - datetime.timedelta(minutes=5)
 
-    def _get_auth_key(self):
-        # todo - calling this when JWT from web flow fails.
-        try:
-            response = self.post(
-                '/__api/start-session',
-                headers={
-                    'Authorization': 'Bearer {}'.format(
-                        self.secret_key
-                    )
-                }
-            )
-        except DatalakeException as e:
-            raise AuthenticationFailure(
-                message='Could not authenticate API key'
-            ) from e
-
-        return response.text
-
     def _get_SAM_auth_key(self):
 
         sam_response = self.post(
@@ -501,8 +482,7 @@ class Session(requests.Session):
         token = sam_response.json()["access_token"]
 
         catalogue_response = self.post(
-            urljoin(self._environment.accounts,
-                    identity_urls.identity_token),
+            urljoin(self._environment.accounts, identity_urls.identity_token),
             data={
                 "client_id": self.access_id,
                 "subject_token": token,
@@ -521,19 +501,23 @@ class Session(requests.Session):
         str_jwt = None
 
         if callback is None:
-            url = f"{self._environment.catalogue}" \
-                  f"{identity_urls.identity_postbox}" \
-                  f"?postbox={postbox}&" \
-                  f"target=/api/identity/v2/auth/postbox_confirmation"
+            '/api/identity/v1/postbox_login?postbox={uuid sans "="}&target=/api/identity/v2/auth/postbox_confirmation'
+            login_url = f"{self._environment.catalogue}" \
+                        f"{identity_urls.identity_postbox}" \
+                        f"?postbox={postbox}&" \
+                        f"target=/api/identity/v2/auth/postbox_confirmation"
+            if self.show_login_url:
+                print(f'Login url is: {login_url}')
+
             # we need to check that the listener can actually listen
             # before we open the browser - so establish that a listener
             # is up and running, or can listen (not firewalled)
             # else we need to tell the user that their firewall is shut.
 
-            isopen=webbrowser.open(url, new=1)
+            isopen=webbrowser.open(login_url, new=1)
             if not isopen:
                 print(f"WARNING: We could not open a usable web browser for authentication purposes, or alternatively,"
-                      f" please copy the below:\n\n{url}\n\nEnter this into a web browser that you can access, "
+                      f" please copy the below:\n\n{login_url}\n\nEnter this into a web browser that you can access, "
                       f"or alternatively, you can use your phone or a web browser on another machine. "
                       f"After this step, by returning here, you will see this console un-blocked.\n"
                       f"If you wish to abort enter Ctrl/Cmd + C on your keyboard.\n\n")
@@ -559,7 +543,7 @@ class Session(requests.Session):
                     str_jwt = query.text
                     _jwt = str.encode(str_jwt)
                     break
-            except TimeoutException as e:
+            except ConnectionException as e:
                 print(
                     "Sorry, the connection timed out. Please try again in "
                     "one minute. If this is your first time trying to connect "
@@ -618,13 +602,6 @@ class Session(requests.Session):
         return str_jwt
 
 
-class Response(ObjectProxy):
-
-    def __init__(self, wrapped, builder, *args, **kwargs):
-        super(Response, self).__init__(wrapped, *args, **kwargs)
-        self.builder = builder
-
-
 class BlockAll(CookiePolicy):
     return_ok = set_ok = domain_return_ok = path_return_ok = lambda self, *args, **kwargs: False
     netscape = True
