@@ -11,6 +11,7 @@ class _Environment:
         'catalogue.datalake.ihsmarkit.com': 'prod',
         'catalogue-testprod.datalake.ihsmarkit.com': 'testprod',
         'catalogue-uat.datalake.ihsmarkit.com': 'uat',
+        'catalogue-uatus.datalake.ihsmarkit.com': 'uatus',
         'client-uat.datalake.ihsmarkit.com': 'uat2',
         'catalogue-dev.udpmarkit.net': 'dev',
         'catalogue-qa.udpmarkit.net': 'qa',
@@ -22,6 +23,7 @@ class _Environment:
         'catalogue.datalake.ihsmarkit.com': 'catalogue.datalake.ihsmarkit.com',
         'catalogue-testprod.datalake.ihsmarkit.com': 'catalogue-testprod.datalake.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 'catalogue-uat.datalake.ihsmarkit.com',
+        'catalogue-uatus.datalake.ihsmarkit.com': 'catalogue-uatus.datalake.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 'client-uat.datalake.ihsmarkit.com',
         'catalogue-dev.udpmarkit.net': 'catalogue-dev.udpmarkit.net',
         'catalogue-qa.udpmarkit.net': 'catalogue-qa.udpmarkit.net',
@@ -33,6 +35,7 @@ class _Environment:
         'catalogue.datalake.ihsmarkit.com': 'consumption.datalake.ihsmarkit.com',
         'catalogue-testprod.datalake.ihsmarkit.com': 'consumption-testprod.datalake.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 'consumption-uat.datalake.ihsmarkit.com',
+        'catalogue-uatus.datalake.ihsmarkit.com': 'consumption-uatus.datalake.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 'consumption-uat2.datalake.ihsmarkit.com',
         'catalogue-dev.udpmarkit.net': 'consumption-dev.udpmarkit.net',
         'catalogue-qa.udpmarkit.net': 'consumption-qa.udpmarkit.net',
@@ -44,6 +47,7 @@ class _Environment:
         'catalogue.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'catalogue-testprod.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
+        'catalogue-uatus.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'catalogue-qa.udpmarkit.net': 'sam.samexternal.net',
         'catalogue-qa2.udpmarkit.net': 'sam.samexternal.net',
@@ -55,6 +59,7 @@ class _Environment:
         'catalogue.datalake.ihsmarkit.com': 'datalake-pkce-prod-q56PXZSTDQ',
         'catalogue-testprod.datalake.ihsmarkit.com': 'datalake-pkce-prod-q56PXZSTDQ',
         'catalogue-uat.datalake.ihsmarkit.com': 'datalake-pkce-uat-RMrWmjPhql',
+        'catalogue-uatus.datalake.ihsmarkit.com': 'datalake-pkce-uat-RMrWmjPhql',
         'client-uat.datalake.ihsmarkit.com': 'datalake-pkce-uat-RMrWmjPhql',
         'catalogue-qa.udpmarkit.net': 'datalake-pkce-sqa-BSFwJUigI4',
         'catalogue-qa2.udpmarkit.net': 'datalake-pkce-sqa-BSFwJUigI4',
@@ -66,6 +71,7 @@ class _Environment:
         'catalogue.datalake.ihsmarkit.com': 's3.datalake.ihsmarkit.com',
         'catalogue-testprod.datalake.ihsmarkit.com': 's3-testprod.datalake.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 's3-uat.datalake.ihsmarkit.com',
+        'catalogue-uatus.datalake.ihsmarkit.com': 's3-uatus.datalake.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 's3-uat2.datalake.ihsmarkit.com',
         'catalogue-qa.udpmarkit.net': 's3-qa.udpmarkit.net',
         'catalogue-qa2.udpmarkit.net': 's3-qa2.udpmarkit.net',
