@@ -26,7 +26,12 @@ class DatalakeException(Exception):
         )
 
     def __str__(self):
-        error = f'\n{self.response.request.method} {self.response.request.url}\n\n'
+        error = '\nProblem with the call to: ' \
+                f'{self.response.request.method} {self.response.request.url}' \
+                '\nPlease do not copy this URL into a browser. ' \
+                "If you need more help please contact support at " \
+                "datalake-support@ihsmarkit.com with this error message " \
+                "including any request_id. \n\n"
 
         try:
             error += (
@@ -38,7 +43,6 @@ class DatalakeException(Exception):
                 f'{self.response.text}'
             )
 
-
         try:
             request_id = self.response.request.headers.get(
                 'X-Request-ID', 'unknown'
@@ -84,10 +88,15 @@ class DataframeStreamingException(DatalakeException):
     def __str__(self):
         msg = json.dumps(self.error, indent=4)
         return f'\n A GET request was made to the following url: ' \
-               f'{self.url}\n\n{msg}'
+               f'{self.url}' \
+               '\nPlease do not copy this URL into a browser. ' \
+               "If you need more help please contact support at " \
+               "datalake-support@ihsmarkit.com with this error message " \
+               "including any request_id. \n\n" \
+               f'\n\n{msg}'
 
 
-class TimeoutException(DatalakeException):
+class ConnectionException(DatalakeException):
     pass
 
 
@@ -104,21 +113,33 @@ class UnAuthorisedAccessException(DatalakeException):
 
 
 class DatalakeGatewayTimeout(DatalakeException):
-    message = (
-        'This request to the Datalake has timed-out. This means that the '
-        'request required too much processing. Please report this error '
-        'to a member of the Datalake support team.'
-    )
+    def __str__(self):
+        error = super().__str__()
+        error += (
+            '\nThis request to the Datalake has timed-out. This means that the '
+            'request required too much processing or our service is under heavy '
+            'load. Your request may still be running on the server, if so we '
+            'will attempt to cache the results and you should try the same call '
+            'again in five minutes. If the problem persists then please report '
+            'this error to a member of the Datalake support team.'
+        )
+        return error
 
 
 class DatalakeServiceUnavailable(DatalakeException):
-    message = (
-        'IHS Markit datalake is unavailable. Please try again in a few seconds.'
-    )
+
+    def __str__(self):
+        error = super().__str__()
+        error += '\nIHS Markit datalake is unavailable. Please try again in a few seconds.'
+        return error
 
 
 class InsufficientPrivilegesException(DatalakeException):
-    message = 'Insufficient privileges to perform this action'
+
+    def __str__(self):
+        error = super().__str__()
+        error += '\nInsufficient privileges to perform this action'
+        return error
 
 
 class S3FileDoesNotExist(DatalakeException):
@@ -130,6 +151,15 @@ class S3FileDoesNotExist(DatalakeException):
 
         super(S3FileDoesNotExist, self).__init__(self.message)
 
+class S3BucketDoesNotExist(DatalakeException):
+    def __init__(self, bucket_name):
+        self.message = (
+            "Either bucket at path `%s` does not exist / Potential issue with the bucket policy."
+            "Please reach out to Datalake Tech Data Ops user for resolution." % bucket_name
+        )
+
+        super(S3BucketDoesNotExist, self).__init__(self.message)
+
 
 class DownloadFailed(DatalakeException):
     pass
