@@ -8,7 +8,6 @@ import os
 import warnings
 import datetime
 import glob
-import s3fs
 import multiprocessing
 
 from concurrent.futures import ThreadPoolExecutor
@@ -18,7 +17,8 @@ from dateutil import tz
 from boto3 import Session
 import botocore
 from urllib.parse import urlparse, ParseResult
-from dli.client.exceptions import InsufficientPrivilegesException, S3FileDoesNotExist
+from dli.client.exceptions import InsufficientPrivilegesException, S3FileDoesNotExist, S3BucketDoesNotExist
+from typing import Dict, List
 
 logger = logging.getLogger(__name__)
 THREADS = multiprocessing.cpu_count()
@@ -26,11 +26,11 @@ THREADS = multiprocessing.cpu_count()
 
 class Client:
     """
-    A wrapper client providing util methods for s3fs
+    A wrapper client providing util methods for boto
     """
 
     @classmethod
-    def from_dataset(cls, client, dataset_id):
+    def from_dataset(cls, client, dataset_id) -> 'Client':
         def _credentials():
             keys = client.get_s3_access_keys_for_dataset(dataset_id)
             expiry_time = (
@@ -47,27 +47,28 @@ class Client:
                 expiry_time=expiry_time
             )
 
-        session_credentials = botocore.credentials.RefreshableCredentials.create_from_metadata(
-            metadata=_credentials(),
-            refresh_using=_credentials,
-            method='NOOP'
-        )
+        session_credentials: botocore.credentials.RefreshableCredentials = \
+            botocore.credentials.RefreshableCredentials.create_from_metadata(
+                metadata=_credentials(),
+                refresh_using=_credentials,
+                method='NOOP'
+            )
 
-        session = botocore.session.get_session()
+        session: Dict = botocore.session.get_session()
         # Extremely dirty but it seems to be the 'blessed' way of doing this.
-        session._credentials = session_credentials
+        session._credentials: botocore.credentials.RefreshableCredentials = session_credentials
         return cls(Session(botocore_session=session))
 
     def __init__(self, boto_session):
         self.boto_session = boto_session
 
         self.s3_resource = self.boto_session.resource(
-            's3', endpoint_url=os.environ.get('S3_URL')
+            's3', endpoint_url=os.environ.get('S3_URL'),
+            # TODO scott: can take  region_name  as a parameter
+            #   DLS-1838 should we pass the region_name if `location` is a boto3 constraint?
         )
 
         self.s3_client = self.s3_resource.meta.client
-        self.s3fs = s3fs.S3FileSystem()
-        self.s3fs.s3 = self.s3_client
 
     def download_files_from_s3_path(self, s3_path, destination, flatten=False):
         """
@@ -138,7 +139,7 @@ class Client:
             destination_path = list(executor.map(_download, keys))
         return destination_path
 
-    def upload_files_to_s3(self, files, s3_location, token_refresher=None, num_retries=None):
+    def upload_files_to_s3(self, files, s3_location) -> List[Dict]:
         """
         Upload multiple files to a specified s3 location. The basename of the
         `files` will be preserved.
@@ -146,32 +147,36 @@ class Client:
         :param List files: An list of filepaths
         :param str s3_location: Path to destination directory in S3, file will be
                  stored under <s3_location><filename>
-        :param token_refresher: Optional Function to refresh S3 token *deprecated*
-        :param int num_retries: Optional Number of retries in case of upload failure *deprecated*
         :returns: List of path to the files in S3
         :rtype: List[str]
         """
-        if token_refresher:
-            warnings.warn(
-                'Credentials are now automatically refreshed.'
-                'This will be removed in the next major release.',
-                DeprecationWarning,
-            )
-
-        if num_retries:
-            warnings.warn(
-                'Retries are handled by boto.'
-                'This will be removed in the next major release.',
-                DeprecationWarning,
-            )
-
 
         bucket_name, *prefix = s3_location.partition('/')
-        bucket = self.s3_resource.Bucket(bucket_name)
+        try:
+            # Verify that the bucket exists to avoid support tickets of people trying to upload
+            # to buckets with wrong spellings or buckets that do not exist.
+            # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/migrations3.html#accessing-a-bucket
+            bucket = self.s3_client.head_bucket(Bucket=bucket_name)
+        except botocore.exceptions.ClientError as e:
+            # If a client error is thrown, then check that it was a 404 error.
+            # If it was a 404 error, then the bucket does not exist.
+            error_code = e.response['Error']['Code']
+            if error_code == '404':
+                raise S3BucketDoesNotExist(bucket_name) from e
+            elif error_code == '403':
+                # AWS permissions are setup in strange ways, like in the case that the user
+                # has permission to upload to s3 but cannot call read operations such as
+                # `head_bucket`. QA had this issue, so it breaks the code that checks if the
+                # bucket exists before uploading.
+                bucket = self.s3_resource.Bucket(bucket_name)
+            else:
+                # All other error_codes should bubble up the original exception.
+                raise
+
         prefix = ''.join(prefix)
 
 
-        def upload(file, s3_location):
+        def upload(file, s3_location) -> Dict:
             file_path = file['file']
             s3_suffix = file['s3_suffix']
             target = os.path.join(prefix, s3_suffix)
@@ -180,7 +185,7 @@ class Client:
 
             try:
                 self.s3_client.upload_file(
-                    file_path, bucket.name, target.lstrip('/')
+                    file_path, bucket_name, target.lstrip('/')
                 )
             except botocore.exceptions.ClientError as e:
                 if e.response['Error']['Code'] == 'AccessDenied':
@@ -274,6 +279,12 @@ class S3DatafileWrapper:
         self._datafile = datafile
         self._client = client
 
+    def as_dict(self):
+        return dict(self._datafile)
+
+    def _asdict(self):
+        return self.as_dict()
+
     def __getitem__(self, path):
         """
         :param str path: The path of the file to retrieve from s3.
