@@ -23,46 +23,47 @@ class DatasetFactory:
         return cls._from_v2_response(response.json())
 
     @classmethod
-    def _from_v2_response(cls, response_json):
+    def _from_v2_response(cls, response_json, warn=False, page_size=25):
         return cls._construct_dataset_using(
-            response_json['data']['attributes'], response_json['data']['id']
+            response_json['data']['attributes'], response_json['data']['id'], warn, page_size=page_size,
         )
 
     @classmethod
-    def _from_v2_response_unsheathed(cls, response_json):
+    def _from_v2_response_unsheathed(cls, response_json, warn=False, page_size=25):
         return cls._construct_dataset_using(
-            response_json['attributes'], response_json['id']
+            response_json['attributes'], response_json['id'], warn, page_size=page_size,
         )
 
     @classmethod
-    def _from_v2_list_response(cls, response_json):
+    def _from_v2_list_response(cls, response_json, page_size=25):
         return [
             cls._construct_dataset_using(
-                dataset['attributes'], dataset['id']
+                dataset['attributes'], dataset['id'], page_size=page_size,
             )
             for dataset in response_json['data']
         ]
 
     @classmethod
-    def _construct_dataset_using(cls, attributes, dataset_id):
-        location = attributes.pop('location')
+    def _construct_dataset_using(cls, attributes, dataset_id, warn=False, page_size=25):
         # In the interests of not breaking backwards compatability.
         # TODO find a way to migrate this to the new nested API.
-        if not location:
-            location = None
-        else:
-            location = location[next(iter(location))]
+        if 'location' in attributes:
+            location = attributes.pop('location')
+            # Note: flattens 's3' field in 'location' - old behaviour we have to keep in order to preserve consumption and sql
+            if location is not None:
+                location = location[next(iter(location))]
+                attributes['location'] = location
 
         # ca depend
         if attributes["content_type"] == "Unstructured":
-            return cls._client.Unstructured(
+            return cls._client._Unstructured(
                 **attributes,
-                location=location,
-                dataset_id=dataset_id
+                dataset_id=dataset_id,
+                warn=warn
             )
         else:
-            return cls._client.Structured(
+            return cls._client._Structured(
                 **attributes,
-                location=location,
+                page_size=page_size,
                 dataset_id=dataset_id
             )
