@@ -475,7 +475,7 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
             .. code-block:: python
                 # Get an exact dataset using the dataset_short_code and
                 # organisation_short_code.
-                >>> dataset = client.get_dataset(dataset_short_code='ExampleDatasetShortCode', organisation_short_code='IHSMarkit')
+                >>> dataset = client.datasets.get(dataset_short_code='ExampleDatasetShortCode', organisation_short_code='IHSMarkit')
                 # Get metadata of the dataset.
                 >>> dataset.metadata()
 
