@@ -137,7 +137,6 @@ def package_request_index_accessible_content_v2():
             'terms_and_conditions': 'Terms',
             'content_types': ['Reference Data'],
             'has_access': True,
-            'data_sensitivity': 'Public',
             'taxonomy': ['Data-IHS Markit-Climate'],
             'contract_ids': [],
             'created_at': '2020-05-13T15:08:07.297885',
@@ -169,7 +168,6 @@ def package_request_index_unaccessible_content_v2():
             'terms_and_conditions': 'Terms',
             'content_types': ['Reference Data'],
             'has_access': False,
-            'data_sensitivity': 'Public',
             'taxonomy': ['Data-Test Org-Finance'],
             'contract_ids': [],
             'created_at': '2020-05-13T15:08:07.297885',
@@ -198,7 +196,12 @@ def dataset_request_index_accessible_content_v2():
              'package_id': '59e6a698-975d-11e9-84cc-7e5ef76d533f',
              'updated_by': 'update@ihsmarkit.com',
              'keywords': [],
-             'location': {},
+             'location': {'s3': {
+                            'aws_role_arn':'123',
+                            'bucket': 'bucketA',
+                            'owner': {},
+                            'prefix': 'abc',
+                            'type': 'S3'}},
              'content_type': 'Structured',
              'has_access': True,
              'first_datafile_at': '2019-05-06',
@@ -226,7 +229,6 @@ def dataset_request_index_unaccessible_content_v2():
              'package_id': '59e6a698-975d-11e9-84cc-0000000000',
              'updated_by': 'update@ihsmarkit.com',
              'keywords': [],
-             'location': {},
              'content_type': 'Structured',
              'has_access': False,
              'first_datafile_at': '2019-05-06',
@@ -271,7 +273,6 @@ def package_request_v2():
                 'hasAccess': True,
                 'description': 'DESC',
                 'documentation': 'href',
-                'dataSensitivity': 'Private',
             }
         }
     }
@@ -286,7 +287,6 @@ def dataset_request_v2():
                      'package_id': '59e6a698-975d-11e9-84cc-7e5ef76d533f',
                      'updated_by': 'update@ihsmarkit.com',
                      'keywords': [],
-                     'location': {},
                      'content_type': 'Structured',
                      'has_access': False,
                      'first_datafile_at': '2019-05-06',
@@ -391,7 +391,6 @@ def unstructured_dataset_request_v2():
                      'package_id': '59e6a698-975d-11e9-84cc-7e5ef76d533f',
                      'updated_by': 'update@ihsmarkit.com',
                      'keywords': [],
-                     'location': {},
                      'content_type': 'Unstructured',
                      'has_access': False,
                      'first_datafile_at': '2019-05-06',
@@ -420,7 +419,13 @@ def unstructured_dataset_request_index_accessible_content_v2():
              'package_id': '59e6a698-975d-11e9-84cc-7e5ef76d533f',
              'updated_by': 'update@ihsmarkit.com',
              'keywords': [],
-             'location': {},
+             'location': {'s3': {
+                            'aws_role_arn':'123',
+                            'bucket': 'bucketA',
+                            'owner': {},
+                            'prefix': 'abc',
+                            'type': 'S3',}
+             },
              'content_type': 'Unstructured',
              'has_access': True,
              'first_datafile_at': '2019-05-06',
@@ -453,7 +458,7 @@ def object_summaries_s3(aws_s3, request):
 
     with freeze_time('2020-01-01T00:00:00Z'):
         s3_resource = boto3.resource('s3')
-        bucket = s3_resource.create_bucket(Bucket='bucket')
+        bucket = s3_resource.create_bucket(Bucket='bucket', CreateBucketConfiguration={'LocationConstraint': 'eu-west-1'})
 
         for root, dirs, files in os.walk(path):
             for file in files:
@@ -474,7 +479,7 @@ def unstructured_object_summaries_s3(aws_s3, request):
 
     with freeze_time('2020-01-01T00:00:00Z'):
         s3_resource = boto3.resource('s3')
-        bucket = s3_resource.create_bucket(Bucket='bucket')
+        bucket = s3_resource.create_bucket(Bucket='bucket', CreateBucketConfiguration={'LocationConstraint': 'eu-west-1'})
 
         for root, dirs, files in os.walk(path):
             for file in files:
